==> bobplates_0.12.10.zip: bobplates_0.12.10/prototypes/recipe/void-recipe.lua <==
data:extend(
{
  {
    type = "recipe",
    name = "void-oxygen",
    category = "void-fluid",
    enabled = "false",
    hidden = "true",
    energy_required = 1,
    ingredients =
    {
      {type="fluid", name="oxygen", amount=2}
    },
    results=
    {
      {type="item", name="void", amount=1, probability=0},
    },
    subgroup = "void",
    icon = "__bobplates__/graphics/icons/void-oxygen.png",
    order = "oxygen"
  },

  {
    type = "recipe",
    name = "void-hydrogen",
    category = "void-fluid",
    enabled = "false",
    hidden = "true",
    energy_required = 1,
    ingredients =
    {
      {type="fluid", name="hydrogen", amount=2},
    },
    results=
    {
      {type="item", name="void", amount=1, probability=0},
    },
    subgroup = "void",
    icon = "__bobplates__/graphics/icons/void-hydrogen.png",
    order = "hydrogen"
  },

  {
    type = "recipe",
    name = "void-nitrogen",
    category = "void-fluid",
    enabled = "false",
    hidden = "true",
    energy_required = 1,
    ingredients =
    {
      {type="fluid", name="nitrogen", amount=2},
    },
    results=
    {
      {type="item", name="void", amount=1, probability=0},
    },
    subgroup = "void",
    icon = "__bobplates__/graphics/icons/void-nitrogen.png",
    order = "nitrogen"
  },

  {
    type = "recipe",
    name = "void-chlorine",
    category = "void-fluid",
    enabled = "false",
    hidden = "true",
    energy_required = 1,
    ingredients =
    {
      {type="fluid", name="chlorine", amount=2},
    },
    results=
    {
      {type="item", name="void", amount=1, probability=0},
    },
    icon = "__bobplates__/graphics/icons/void-chlorine.png",
    subgroup = "void",
    order = "chlorine"
  },
}
)

==> bobplates_0.15.5.zip: bobplates_0.15.5/prototypes/recipe/void-recipe.lua <==
data:extend(
{
  {
    type = "recipe",
    name = "void-oxygen",
    category = "void-fluid",
    hidden = "true",
    energy_required = 1,
    ingredients =
    {
      {type="fluid", name="oxygen", amount=25}
    },
    results=
    {
      {type="item", name="void", amount=1, probability=0},
    },
    subgroup = "void",
    icon = "__bobplates__/graphics/icons/void-oxygen.png",
    order = "oxygen"
  },

  {
    type = "recipe",
    name = "void-hydrogen",
    category = "void-fluid",
    hidden = "true",
    energy_required = 1,
    ingredients =
    {
      {type="fluid", name="hydrogen", amount=20},
    },
    results=
    {
      {type="item", name="void", amount=1, probability=0},
    },
    subgroup = "void",
    icon = "__bobplates__/graphics/icons/void-hydrogen.png",
    order = "hydrogen"
  },

  {
    type = "recipe",
    name = "void-nitrogen",
    category = "void-fluid",
    hidden = "true",
    energy_required = 1,
    ingredients =
    {
      {type="fluid", name="nitrogen", amount=20},
    },
    results=
    {
      {type="item", name="void", amount=1, probability=0},
    },
    subgroup = "void",
    icon = "__bobplates__/graphics/icons/void-nitrogen.png",
    order = "nitrogen"
  },

  {
    type = "recipe",
    name = "void-chlorine",
    category = "void-fluid",
    hidden = "true",
    energy_required = 1,
    ingredients =
    {
      {type="fluid", name="chlorine", amount=25},
    },
    results=
    {
      {type="item", name="void", amount=1, probability=0},
    },
    icon = "__bobplates__/graphics/icons/void-chlorine.png",
    subgroup = "void",
    order = "chlorine"
  },

  {
    type = "recipe",
    name = "void-sulfur-dioxide",
    category = "void-fluid",
    hidden = "true",
    energy_required = 1,
    ingredients =
    {
      {type="fluid", name="sulfur-dioxide", amount=20},
    },
    results=
    {
      {type="item", name="void", amount=1, probability=0},
    },
    icon = "__bobplates__/graphics/icons/void-sulfur-dioxide.png",
    subgroup = "void",
    order = "sulfur-dioxide"
  },
}
)
